@@ -28,14 +28,14 @@ from .file_data_managers import environment_default, environment_bold_escaped, C
 from .formatting_functions.common import fecha, pesos, porcentaje
 from .gui_functions import generate_ingresos, pago_factura, find_ajustes, format_concepto_desc, exportar_facturas, exportar_facturas_filename, parse_ym_date
 from .layout import make_layout, InvoiceButtonManager, EmailButtonManager
-from .log_tools import LogHandler, LogAdapter, log_line, log_item, cfdi_header
+from .log_tools import log_line, log_item, cfdi_header, print_yaml
 from .mycfdi import get_all_cfdi, MyCFDI, move_to_folder, local_db, PPD, PUE
 
-logging.basicConfig(level=logging.INFO)
+
 logging.getLogger("weasyprint").setLevel(logging.ERROR)
 logging.getLogger("fontTools").setLevel(logging.ERROR)
 
-logger = LogAdapter(logging.getLogger())
+logger = logging.getLogger(__name__)
 
 AJUSTES_DIR = "ajustes"
 template = environment_default.get_template(
@@ -43,8 +43,16 @@ template = environment_default.get_template(
 )
 
 
+def is_uuid(s):
+    try:
+        UUID(s)
+        return True
+    except ValueError:
+        return False
+
+
 class FacturacionGUI:
-    def __init__(self, pac_service, csd_signer: Signer, email_manager, fiel_signer=None, concepto_adapter=None):
+    def __init__(self, pac_service, csd_signer: Signer, email_manager, fiel_signer=None, concepto_adapter=None, debug=False):
         self.email_manager = email_manager
         self.pac_service = pac_service
         self.sat_service = SAT(
@@ -65,15 +73,12 @@ class FacturacionGUI:
         window = PySimpleGUI.Window(
             f"Facturacion 4.0  RazonSocial: {self.issuer.legal_name}  RFC: {self.issuer.rfc}  "
             f"Serie: {local.config.serie()}  Regimen: {self.issuer.tax_system}  LugarExpedicion: {self.lugar_expedicion}",
-            make_layout(fiel_signer is not None),
+            make_layout(fiel_signer is not None, debug=debug),
             size=(1280, 800),
             resizable=True,
         )
         self.window = window
-
-        self.ch = LogHandler(self.window['console'])
-        self.ch.setLevel(logging.INFO)
-        logging.getLogger().addHandler(self.ch)
+        self.console = self.window['console']
 
         self.invoice_button_manager = InvoiceButtonManager(window["crear_facturas"], window["detallado"])
         self.email_button_manager = EmailButtonManager(window["enviar_correos"])
@@ -100,7 +105,7 @@ class FacturacionGUI:
                 }
 
         try:
-            logger.info_yaml({
+            print_yaml({
                 "version": __version__.__version__,
                 "facturacion": "CFDI 4.0",
                 "emisor": self.issuer_cif,
@@ -162,7 +167,7 @@ class FacturacionGUI:
                     file_attachments=attachments
                 )
 
-                self.window.read(timeout=0)
+                self._read()
 
                 for r in notify_invoices:
                     r.notified = ",".join(to_addrs)
@@ -171,15 +176,15 @@ class FacturacionGUI:
         response = self.sat_service.recover_comprobante_status(
             id_solicitud=id_solicitud
         )
-        logger.info_yaml(response)
-        self.window.read(timeout=0)
+        print_yaml(response)
+        self._read()
         if response["EstadoSolicitud"] == EstadoSolicitud.Terminada:
             for id_paquete in response['IdsPaquetes']:
                 response, paquete = self.sat_service.recover_comprobante_download(
                     id_paquete=id_paquete
                 )
-                logger.info_yaml(response)
-                self.window.read(timeout=0)
+                print_yaml(response)
+                self._read()
                 yield id_paquete, base64.b64decode(paquete) if paquete else None
 
     def unzip_cfdi(self, file):
@@ -187,8 +192,13 @@ class FacturacionGUI:
             for fileinfo in zf.infolist():
                 xml_data = zf.read(fileinfo)
                 move_to_folder(xml_data, pdf_data=None)
-                self.window.read(timeout=0)
+                self._read()
 
+    def _read(self):
+        event, values = self.window.read(timeout=0)
+        if event in ("Exit", PySimpleGUI.WIN_CLOSED):
+            exit(0)
+        
     def generate_pdf_template(self, template_name, fields):
         increment_template = environment_bold_escaped.get_template(template_name)
         md5_document = increment_template.render(
@@ -230,16 +240,16 @@ class FacturacionGUI:
             res = None
             for i in self.get_all_invoices().values():
                 if i.name == text and i["Emisor"]["Rfc"] == emisor_rfc:
-                    logger.info(f"Factura Encontrada: {i['Receptor']['Rfc']}  {i.name}  {i.uuid}  {i['Fecha']}")
+                    print(f"Factura Encontrada: {i['Receptor']['Rfc']}  {i.name}  {i.uuid}  {i['Fecha']}")
                     if res:
-                        logger.info(f"Multiples Facturas Encontradas con el mismo nombre: {text}")
+                        print(f"Multiples Facturas Encontradas con el mismo nombre: {text}")
                         return
                     res = i
             if res:
                 return res
-        logger.info(f"Factura No Encontrada {text}")
+        print(f"Factura No Encontrada {text}")
 
-    def log_cfdi(self, cfdi: CFDI):
+    def log_cfdi(self, cfdi: CFDI, ver_saldo=True):
         cfdi_copy = cfdi.copy()
         del cfdi_copy["Certificado"]
         del cfdi_copy["Sello"]
@@ -289,10 +299,10 @@ class FacturacionGUI:
                 if timbre_fiscal_digital := complemento.get("TimbreFiscalDigital"):
                     cfdi_copy["Complemento"]["TimbreFiscalDigital"] = timbre_fiscal_digital['UUID']
 
-        if isinstance(cfdi, SatCFDI):
+        if isinstance(cfdi, SatCFDI) and ver_saldo:
             cfdi_copy["_saldo_pendiente"] = cfdi.saldo_pendiente
 
-        logger.info_yaml(cfdi_copy)
+        print_yaml(cfdi_copy)
 
     def main_loop(self):
         factura_seleccionada = None  # type: MyCFDI | None
@@ -305,7 +315,7 @@ class FacturacionGUI:
                     return
 
                 if event not in ("crear_facturas", "enviar_correos", "confirm_pago_button", "ver_factura", "ver_excel"):
-                    self.ch.clear()
+                    self.console.update("")
                 invoices_to_create = self.invoice_button_manager.clear()
                 emails_to_send = self.email_button_manager.clear()
 
@@ -315,44 +325,47 @@ class FacturacionGUI:
 
                     case "factura_pagar" | "buscar_factura":
                         text = self.window["factura_pagar"].get().strip()
-                        if event == "buscar_factura":
-                            factura_seleccionada = self.factura_uuid(text)
-                            if not factura_seleccionada:
-                                factura_seleccionada = self.factura_buscar(text)
-                        else:
-                            factura_seleccionada = self.factura_uuid(text)
+                        factura_seleccionada = self.factura_uuid(text)
+                        if event == "buscar_factura" and not factura_seleccionada:
+                            factura_seleccionada = self.factura_buscar(text)
 
                         if factura_seleccionada:
                             self.log_cfdi(factura_seleccionada)
                             local_db.describe(factura_seleccionada)
 
-                        not_ppd_all = not factura_seleccionada or factura_seleccionada.get("MetodoPago") != PPD or factura_seleccionada.estatus != "1"
-                        not_ppd = not_ppd_all or factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
+                        not_ppd_all = not factura_seleccionada \
+                                      or factura_seleccionada.get("MetodoPago") != PPD \
+                                      or factura_seleccionada.estatus != "1"
+                        not_ppd = not_ppd_all \
+                                  or factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
 
-                        not_pue = not factura_seleccionada or factura_seleccionada.get("MetodoPago") != PUE or factura_seleccionada.estatus != "1" or \
+                        not_pue = not factura_seleccionada \
+                                  or factura_seleccionada.get("MetodoPago") != PUE \
+                                  or factura_seleccionada.estatus != "1" or \
                                   factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
 
                         self.window["status_sat"].update(disabled=not factura_seleccionada)
-                        self.window["pago_pue"].update(disabled=not_pue)
+
+                        self.window["pago_pue"].update(
+                            disabled=not_pue
+                                     or factura_seleccionada["Fecha"] <= local.config['pue_pagada_hasta']
+                        )
                         self.window["email_notificada"].update(
                             disabled=not factura_seleccionada
                                      or factura_seleccionada["Emisor"]["Rfc"] != self.issuer.rfc
+                                     or factura_seleccionada["Fecha"] <= local.config['email_notificada_hasta']
                         )
+                        self.window["ignorar_ppd"].update(
+                            disabled=not_ppd_all
+                                     or factura_seleccionada["Fecha"] <= local.config['ppd_ignorar_hasta']
+                        )
+
                         self.window["ver_factura"].update(disabled=not factura_seleccionada)
 
-                        self.window["ignorar_ppd"].update(disabled=not_ppd_all)
                         self.window["prepare_pago"].update(disabled=not_ppd)
                         self.window["fecha_pago_select"].update(disabled=not_ppd)
                         self.window["fecha_pago"].update(disabled=not_ppd)
                         self.window["forma_pago"].update(disabled=not_ppd)
-
-                        def is_uuid(s):
-                            try:
-                                UUID(s)
-                                return True
-                            except ValueError:
-                                return False
-
                         self.window["descarga"].update(disabled=not is_uuid(text))
 
                     case "preparar_ajuste_anual":
@@ -387,12 +400,12 @@ class FacturacionGUI:
                             }
 
                             log_item(f"CARTA INCREMENTO NUMERO: {i}")
-                            logger.info_yaml(data)
+                            print_yaml(data)
                             res = self.generate_pdf_template(template_name='incremento_template.md', fields=data)
                             file_name = f'{AJUSTES_DIR}/AjusteRenta_{rfc}_{concepto["CuentaPredial"]}.pdf'
                             with open(file_name, 'wb') as f:
                                 f.write(res)
-                            self.window.read(timeout=0)
+                            self._read()
 
                         if has_ajustes:
                             os.startfile(
@@ -406,8 +419,7 @@ class FacturacionGUI:
                         id_solicitud = local.config.get(event)
 
                         if not id_solicitud:
-                            logger.info("Creando Nueva Solicitud")
-                            self.window.read(timeout=0)
+                            self._read()
                             response = self.sat_service.recover_comprobante_request(
                                 fecha_inicial=fecha_inicial,
                                 fecha_final=fecha_final,
@@ -415,14 +427,15 @@ class FacturacionGUI:
                                 rfc_emisor=self.sat_service.signer.rfc if "recuperar_emitidas" == event else None,
                                 tipo_solicitud=TipoDescargaMasivaTerceros.CFDI,
                             )
-                            logger.info_yaml(response)
+                            print_yaml(response)
                             local.config[event] = response['IdSolicitud']
                             local.config.save()
+                            print("Nueva Solicitud Creada")
                         else:
-                            logger.info_yaml({
+                            print_yaml({
                                 'IdSolicitud': id_solicitud
                             })
-                            self.window.read(timeout=0)
+                            self._read()
                             for paquete_id, data in self.recupera_comprobantes(id_solicitud):
                                 if data:
                                     self.all_invoices = None
@@ -442,7 +455,7 @@ class FacturacionGUI:
                         if res == "OK":
                             for rfc, details in clients.items():
                                 log_item(f"VALIDANDO {rfc}")
-                                self.window.read(timeout=0)
+                                self._read()
                                 validar_client(rfc, details)
                             log_item("FIN")
                         else:
@@ -486,7 +499,7 @@ class FacturacionGUI:
                         log_line("STATUS")
                         if i := factura_seleccionada:
                             estado = local_db.status_sat(i, update=True)
-                            logger.info_yaml(estado)
+                            print_yaml(estado)
                             local_db.describe(i)
 
                     case "pago_pue":
@@ -500,11 +513,11 @@ class FacturacionGUI:
                                 button_type=POPUP_BUTTONS_OK_CANCEL,
                             )
                             if res == "OK":
-                                self.ch.clear()
+                                self.console.update("")
                                 local_db.pue_pagada_set(i.uuid, not st)
                                 self.log_cfdi(i)
                                 local_db.describe(i)
-                                logger.info(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}PAGADA")
+                                print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}PAGADA")
 
                     case "ignorar_ppd":
                         if i := factura_seleccionada:
@@ -517,11 +530,11 @@ class FacturacionGUI:
                                 button_type=POPUP_BUTTONS_OK_CANCEL,
                             )
                             if res == "OK":
-                                self.ch.clear()
+                                self.console.update("")
                                 local_db.ppd_ignorar_set(i.uuid, not st)
                                 self.log_cfdi(i)
                                 local_db.describe(i)
-                                logger.info(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}IGNORADA")
+                                print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}IGNORADA")
 
                     case "email_notificada":
                         if i := factura_seleccionada:
@@ -534,11 +547,11 @@ class FacturacionGUI:
                                 button_type=POPUP_BUTTONS_OK_CANCEL,
                             )
                             if res == "OK":
-                                self.ch.clear()
+                                self.console.update("")
                                 local_db.email_notificada_set(i.uuid, not st)
                                 self.log_cfdi(i)
                                 local_db.describe(i)
-                                logger.info(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}NOTIFICADA")
+                                print(f"FACTURA MARCADA COMO {'-NO- ' if st else ''}NOTIFICADA")
 
                     case "crear_facturas":
                         log_line("CREAR FACTURAS")
@@ -552,12 +565,14 @@ class FacturacionGUI:
                             for invoice in invoices_to_create:
                                 try:
                                     cfdi = self.generate_invoice(invoice=invoice)
-                                    logger.info(f'Factura Generada: {cfdi_header(cfdi)}')
-                                    self.window.read(timeout=0)
+                                    print_yaml({
+                                        "FacturaGenerada": cfdi_header(cfdi),
+                                    })
+                                    self._read()
                                 except ResponseError as ex:
                                     logger.error(f'Error Generando: {cfdi_header(MyCFDI(invoice))}')
                                     logger.error(f"Status Code: {ex.response.status_code}")
-                                    logger.info_yaml(ex.response.json())
+                                    print_yaml(ex.response.json())
                                     break
                             log_item("FIN")
                         else:
@@ -596,7 +611,7 @@ class FacturacionGUI:
                                 cfdi_correos
                             )
                         else:
-                            logger.info("No hay correos pendientes de enviar")
+                            print("No hay correos pendientes de enviar")
 
                     case "enviar_correos":
                         log_line("ENVIAR CORREOS")
@@ -640,7 +655,7 @@ class FacturacionGUI:
                                     for i in fac_pen
                                 ]
                             }
-                            logger.info_yaml(f)
+                            print_yaml(f)
 
                     case "descarga":
                         log_line('DESCARGADA')
@@ -648,9 +663,9 @@ class FacturacionGUI:
                             res = self.pac_service.recover(values["factura_pagar"], accept=Accept.XML_PDF)
                             self.all_invoices = None
                             cfdi = move_to_folder(res.xml, pdf_data=res.pdf)
-                            self.log_cfdi(cfdi)
+                            self.log_cfdi(cfdi, ver_saldo=False)
                         except DocumentNotFoundError:
-                            logger.info("Factura no encontrada")
+                            print("Factura no encontrada")
 
                     case "exportar_facturas":
                         log_line("EXPORTAR FACTURAS")
