@@ -7,18 +7,17 @@ from decimal import Decimal
 from typing import MutableMapping
 from uuid import UUID
 
-import diskcache
+from satcfdi import CFDI
 from satcfdi.accounting import complement_invoices_data, SatCFDI
 
-from .local import local_db
+from .local import local_db, load_data, save_data
 
-ALL_INVOICES = b'all_invoices'
-ALL_RETENCIONES = b'all_retenciones'
-logger = logging.getLogger()
+ALL_INVOICES = 'all_invoices'
+ALL_RETENCIONES = 'all_retenciones'
+logger = logging.getLogger(__name__)
 
 PPD = "PPD"
 PUE = "PUE"
-cache = diskcache.Cache(".data/tmp")
 
 
 class MyCFDI(SatCFDI):
@@ -161,7 +160,7 @@ def move_to_folder(xml_data, pdf_data):
     try:
         with open(full_name + ".xml", 'xb') as fp:
             fp.write(xml_data)
-        logger.info("Factura ha sido agregada: '%s'", full_name)
+        print(f"Factura ha sido agregada: '{full_name}'")
 
         if pdf_data:
             with open(full_name + ".pdf", 'wb') as fp:
@@ -172,27 +171,27 @@ def move_to_folder(xml_data, pdf_data):
             except:
                 logger.exception("Fallo crear PDF: '%s'", full_name)
     except FileExistsError:
-        logger.info("Factura ya se tenia: %s", full_name)
+        print(f"Factura ya se tenia: '{full_name}'", full_name)
 
     return cfdi
 
 
 def get_all_cfdi() -> Mapping[UUID, MyCFDI]:
-    all_invoices = cache.get(ALL_INVOICES, {})
+    all_invoices = load_data(ALL_INVOICES, {})
 
     has_updates = MyCFDI.get_all_invoices(invoices=all_invoices, search_path="facturas/**/*.xml")
     if has_updates:
-        cache[ALL_INVOICES] = all_invoices
+        save_data(ALL_INVOICES, all_invoices)
 
     complement_invoices_data(all_invoices)
     return all_invoices
 
 
 def get_all_retenciones() -> Mapping[UUID, MyCFDI]:
-    all_invoices = cache.get(ALL_RETENCIONES, {})
+    all_invoices = load_data(ALL_RETENCIONES, {})
 
     has_updates = MyCFDI.get_all_invoices(invoices=all_invoices, search_path="retenciones/**/*.xml")
     if has_updates:
-        cache[ALL_RETENCIONES] = all_invoices
+        save_data(ALL_RETENCIONES, all_invoices)
 
     return all_invoices
